# Generated by Django 2.2.5 on 2019-09-18 01:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('auditlog', '0002_auto_20190913_0219'),
    ]

    operations = [
        migrations.AddField(
            model_name='auditlog',
            name='objeto',
            field=models.CharField(default='algum objeto', max_length=256),
        ),
    ]
