# Generated by Django 2.2.5 on 2019-09-13 02:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('auditlog', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='auditlog',
            name='usuario',
            field=models.CharField(max_length=256),
        ),
    ]
